@@ -6,6 +6,8 @@
 
 use std::io::{self, Read, Write};
 
+use crate::vec_buf::VecBuf;
+
 use super::{
     crypto::CryptoStore,
     layer::{SecureLayer, SecureLayerError},
@@ -13,7 +15,7 @@ use super::{
 
 pub struct SecureStream<S> {
     layer: SecureLayer<S>,
-    read_buf: Vec<u8>,
+    read_buf: VecBuf,
 }
 
 impl<S> SecureStream<S> {
@@ -40,34 +42,11 @@ impl<S> SecureStream<S> {
 
 impl<S: Read> Read for SecureStream<S> {
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
-        if self.read_buf.len() < buf.len() {
-            let read = self.layer.read().map_err(io_error_map)?;
+        let chunk = self.layer.read().map_err(io_error_map)?;
 
-            if read.len() >= buf.len() {
-                let len = buf.len();
-                buf.copy_from_slice(&read[..len]);
-                if read.len() > buf.len() {
-                    self.read_buf.extend_from_slice(&read[len..]);
-                }
+        self.read_buf.push(chunk);
 
-                return Ok(len);
-            } else {
-                self.read_buf.extend_from_slice(&read);
-            }
-        }
-
-        while self.read_buf.len() < buf.len() {
-            let read = self.layer.read().map_err(io_error_map)?;
-
-            self.read_buf.extend_from_slice(&read);
-        }
-
-        let len = buf.len();
-
-        buf.copy_from_slice(&self.read_buf[..len]);
-        self.read_buf.drain(..len);
-
-        Ok(len)
+        self.read_buf.read(buf)
     }
 }
 
@@ -87,7 +66,7 @@ impl<S> From<SecureLayer<S>> for SecureStream<S> {
     fn from(layer: SecureLayer<S>) -> Self {
         Self {
             layer,
-            read_buf: Vec::new(),
+            read_buf: VecBuf::new(),
         }
     }
 }
